<?php
require_once(DIR_SYSTEM.'library/vtbpay/vendor/autoload.php');

use \Vtbpay\Classes\Api\VtbApi,
    \Vtbpay\Classes\Common\VtbPayLogger;

class Vtbpay {

    public VtbApi $api;
    public VtbPayLogger $logger;


    /**
     * Get VTB API instance
     *
     * Returns an instance of the VTB API using configuration values.
     *
     * @return self
     */
    public function setVtbPayApi(
        $client_id,
        $client_secret,
        $test_mode,
        $merchant_authorization
    ): self {
        $this->api = new VtbApi(
            $client_id,
            $client_secret,
            $test_mode,
            $merchant_authorization
        );
        return $this;
    }


    /**
     * Инициализация и настройка объекта класса VtbPayLogger.
     *
     * Эта функция инициализирует и настраивает логгер, используемый плагином VtbPay для ведения журнала.
     *
     * @return self
     */
    public function setVtbPayLogger($logging = false): self
    {
        $oc_log = new Log('vtbpay-' . date('d-m-Y') . '.log');

        $this->logger = VtbPayLogger::getInstance()
                        ->setOption('showCurrentDate', false)
                        ->setCustomRecording(function($message) use ($oc_log){
                            $oc_log->write($message);
                        }, VtbPayLogger::LOG_LEVEL_ERROR)
                        ->setCustomRecording(function($message) use ($oc_log, $logging){
                            if ($logging) $oc_log->write($message);
                        }, VtbPayLogger::LOG_LEVEL_DEBUG);

        return $this;
    }

}
